==> civicrm_5.11.0+dfsg.orig.tar.xz: civicrm/Civi/API/Event/PrepareEvent.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2019                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

namespace Civi\API\Event;

/**
 * Class PrepareEvent
 * @package Civi\API\Event
 */
class PrepareEvent extends Event {
  /**
   * @param array $apiRequest
   *   The full description of the API request.
   * @return PrepareEvent
   */
  public function setApiRequest($apiRequest) {
    $this->apiRequest = $apiRequest;
    return $this;
  }

}

==> civicrm_5.18.1+dfsg.orig.tar.xz: civicrm/Civi/API/Event/PrepareEvent.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2019                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

namespace Civi\API\Event;
use Civi\API\Provider\WrappingProvider;

/**
 * Class PrepareEvent
 * @package Civi\API\Event
 */
class PrepareEvent extends Event {

  /**
   * @param array $apiRequest
   *   The full description of the API request.
   * @return PrepareEvent
   */
  public function setApiRequest($apiRequest) {
    $this->apiRequest = $apiRequest;
    return $this;
  }

  /**
   * Replace the normal implementation of an API call with some wrapper.
   *
   * The wrapper has discretion to call -- or not call -- or iterate with --
   * the original API implementation, with original or substituted arguments.
   *
   * Ex:
   *
   * $event->wrapApi(function($apiRequest, $continue){
   *   echo "Hello\n";
   *   $continue($apiRequest);
   *   echo "Goodbye\n";
   * });
   *
   * @param callable $callback
   *   The custom API implementation.
   *   Function(array $apiRequest, callable $continue).
   * @return PrepareEvent
   */
  public function wrapApi($callback) {
    $this->apiProvider = new WrappingProvider($callback, $this->apiProvider);
    return $this;
  }

}
